@@ -412,7 +412,7 @@ def _syncgroups(hubname = "", purgeorphans = True, addgroupmemberships = True, g
 
 		try:
 			print "syncing group '" + dgroup.cn + "' to ldap"
-			add_ldap_group(gdroup.cn, dgroup.description, dgroup.gidNumber, dgroupMembers)
+			add_ldap_group(dgroup.cn, dgroup.description, dgroup.gidNumber, dgroupMembers)
 		except ldap.ALREADY_EXISTS:
 			delete_ldap_group(dgroup.cn)
 			add_ldap_group(dgroup.cn, dgroup.description, dgroup.gidNumber, groupMembers)
